"""These are the basic Webviz configuration plugins, distributed through
the utility itself.
"""

import warnings

try:
    # Python 3.8+
    from importlib.metadata import distributions
except ModuleNotFoundError:
    # Python < 3.8
    from importlib_metadata import distributions  # type: ignore

from ._utils import load_webviz_plugins_with_metadata, PluginProjectMetaData


with warnings.catch_warnings():
    # As of Sep. 30th 2021, dash-bootstrap-components on PyPI
    # (https://pypi.org/project/dash-bootstrap-components/)
    # did not have a new version using dash==2.0 import statements.
    # Ignore warnings temporarily from that module in order to not
    # confuse end users.
    warnings.filterwarnings(
        "ignore", category=UserWarning, module="dash_bootstrap_components._table"
    )

    PLUGIN_METADATA, PLUGIN_PROJECT_METADATA = load_webviz_plugins_with_metadata(
        distributions(), globals()
    )



from enum import Enum
from pathlib import Path


class WebvizRunMode(Enum):
    NON_PORTABLE = 1
    PORTABLE = 2
    BUILDING_PORTABLE = 3


class WebvizInstanceInfo:
    """Class containing global info regarding the running webviz app instance"""

    def __init__(self, run_mode: WebvizRunMode, storage_folder: Path):
        self._run_mode = run_mode
        self._storage_folder = storage_folder

    @property
    def run_mode(self) -> WebvizRunMode:
        return self._run_mode

    @property
    def storage_folder(self) -> Path:
        return self._storage_folder
